@@ -1,7 +1,7 @@
 package TAP::DOM::Archive;
 our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Handle TAP:Archive files
-$TAP::DOM::Archive::VERSION = '0.93';
+$TAP::DOM::Archive::VERSION = '0.94';
 use 5.006;
 use strict;
 use warnings;
@@ -28,7 +28,7 @@ sub new {
             }
         }
 
-        my $tap_documents = _read_tap_from_archive(\%args);
+        my $tap_documents = _read_tap_from_archive(\%args, \%tap_dom_args);
 
         my $tap_dom_list  = {
             meta => $tap_documents->{meta},
@@ -43,7 +43,7 @@ sub new {
 
 sub _read_tap_from_archive
 {
-        my ($args) = @_;
+        my ($args, $tap_dom_args) = @_;
 
         require Archive::Tar;
         require YAML::Tiny;
@@ -54,6 +54,20 @@ sub _read_tap_from_archive
         my $content;
         if ($args->{filecontent}) {
             $content = $args->{filecontent};
+        } elsif (-z $args->{source} and $tap_dom_args->{noempty_tap}) {
+            return ({
+              meta => {
+                file_order => [ 't/error-tap-archive-was-empty.t' ],
+                file_attributes => [{
+                  start_time  => '1.0',
+                  end_time    => '2.0',
+                  description => 't/error-tap-archive-was-empty.t'
+                }],
+                'start_time' => '1',
+                'stop_time'  => '2',
+              },
+              tap => [ $TAP::DOM::noempty_tap ],
+            });
         } else {
             $content = do {
                 local $/;
@@ -162,7 +176,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Steffen Schwigon.
+This software is copyright (c) 2022 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
